/* REPLICATION CODE FOR STUDY OF HUMAN RIGHTS AND CORRUPTION FOCUSING ON THE WORLD VALUES SURVEY */ 

*****************************************************************
* Start with the full WVS dataset
*****************************************************************

* Replace the folder name with the appropriate one on your computer
gl root "C:\WBG\github\204-v4\Replication package\Stata code and files"

sysdir set PLUS "${root}\ado"
set varabbrev on



use "WVS_Cross-National_Wave_7_Stata_v5_0.dta", clear

keep A_YEAR B_COUNTRY B_COUNTRY_ALPHA S025
decode B_COUNTRY, gen(COUNTRY)
duplicates drop B_COUNTRY A_YEAR, force
rename B_COUNTRY B_ECONOMY
rename B_COUNTRY_ALPHA B_ECONOMY_ALPHA
save "WVS economy codes.dta", replace

* Note: The study used version 5 of the Wave 7 WVS dataset. Version 6 should produce the same results, except with the addition of two countries.
use "WVS_Cross-National_Wave_7_Stata_v5_0.dta", clear

save TEMP, replace

*****************************************************************
* Useful variables
*****************************************************************

* ISO alpha-3 country code / economy code
des B_COUNTRY_ALPHA

rename B_COUNTRY B_ECONOMY
rename B_COUNTRY_ALPHA B_ECONOMY_ALPHA
label var B_ECONOMY B_ECONOMY
label var B_ECONOMY_ALPHA B_ECONOMY_ALPHA

* Country / economy name and year
des S025

/*
"Many things are desirable, but not all of them are essential characteristics of democracy. Please tell me for each of the following things how essential you think it is as a characteristic of democracy. Use this scale where 1 means "not at all an essential characteristic of democracy" and 10 means it definitely is "an essential characteristic of democracy" (read out and code one answer for each):
Interviewer, do not read this and code only if mentioned by the respondent him-herself/: 0 - `It is against democracy'
1= Not an essential characteristic of democracy
10= An essential characteristic of democracy

Q243: People choose their leaders in free elections.
Q244: People receive state aid for unemployment.
Q246: Civil rights protect people from state oppression.
Q249: Women have the same rights as men."

"Please tell me for each of the following actions whether you think it can always be justified, never be justified, or something in between, using this card. (Read out and code one answer for each statement):
1= Never justifiable
10= Always justifiable
Q181: Someone accepting a bribe in the course of their duties"
*/

* Democracy defined by people choosing their leaders in free elections
des Q243

* Democracy defined by people receiving state aid for unemployment
des Q244

* Democracy defined by civil right protect liberty against by state oppression
des Q246

* Democracy defined by women having the same rights as men
des Q249

* Justifiability of someone accepting a bribe in the course of their duties
des Q181


*****************************************************************
* Keep only those used in the analysis and save a shorter replication version
*****************************************************************

keep Q243 Q244 Q246 Q249 Q181 B_ECONOMY
save "WVS_key_variables.dta", replace

clear

*****************************************************************
* Analysis using the smaller dataset
*****************************************************************
use "WVS_key_variables.dta", clear
save TEMP, replace

foreach var of varlist Q243 Q244 Q246 Q249 Q181 {
	replace `var' = . if `var' < 1
}


*****************************************************************
* Create an economy-level dataset. 
*****************************************************************
collapse Q243 Q244 Q246 Q249 Q181 , by(B_ECONOMY)

* Economy codes are merged in for use as markers in the charts. These are codes from the WVS dataset, backed out before the collapse command, and reintroduced to the economy-level dataset.
sort B_ECONOMY
merge 1:1 B_ECONOMY using "WVS economy codes.dta"

gen client = .
order S025 client

replace client = 1 if inlist(B_ECONOMY_ALPHA, "ARG", "BGD", "ARM", "BOL", "BRA", "MMR", "CHL", "CHN", "COL")
replace client = 1 if inlist(B_ECONOMY_ALPHA, "ECU", "ETH", "GTM", "IDN", "IRQ", "KAZ", "JOR", "KEN")
replace client = 1 if inlist(B_ECONOMY_ALPHA, "KGZ", "LBN", "LBY", "MYS", "MDV", "MEX", "MNG", "MAR", "NIC")
replace client = 1 if inlist(B_ECONOMY_ALPHA, "NGA", "PAK", "PER", "PHL", "ROU", "RUS", "SRB", "VNM")
replace client = 1 if inlist(B_ECONOMY_ALPHA, "ZWE", "TJK", "THA", "TUN", "TUR", "UKR", "EGY", "URY", "VEN")

label var Q243 "People choose their leaders in free elections ..."
label var Q244 "People receive state aid for unemployment ..."
label var Q246 "Civil rights protect people from state oppression ..."
label var Q249 "Women have the same rights as men ..."
label var Q181 "Justifiability of someone accepting a bribe ... 1=never, 10=always"

gen avg_rights = (Q243 + Q244 + Q246 + Q249) / 4
label var avg_rights "Average of four key rights areas: 1-not essential for democracy  ... 10=essential for democracy"

save "WVS figures.dta", replace

save TEMP, replace

*****************************************************************
* Use the economy-level dataset to create scatter plots
* Note: The scatter plots appearing in the report were generated using Excel or other programs for the sake of appearance.
*       The PNG versions generated here can be used for comparison.
*****************************************************************
use "WVS figures.dta", clear

save TEMP, replace

********
*  FIGURE 5

* justifiability of corruption (inverse of moral condemnation of corruption) vs degree to which civil rights provide protection against the state are essential for democracy
sum Q246 Q181 if client == 1
scatter Q246 Q181 if client == 1, mlabel(B_ECONOMY_ALPHA) msymbol(0) mlabpos(0) ms(i) mlabsize(3) xline(2.10524) yline(7.179497) 
graph export figure5.png, replace

********
*  FIGURE 6

* justifiability of corruption (inverse of moral condemnation of corruption) vs women have same rights as men important for democracy
sum Q249 Q181 if client == 1
scatter Q249 Q181 if client == 1, mlabel(B_ECONOMY_ALPHA) msymbol(0) mlabpos(0) ms(i) xline(2.10524) yline(7.767254) mlabsize(3)
graph export figure6.png, replace

********
*  FIGURE 7


* justifiability of corruption (inverse of moral condemnation of corruption) vs people choose leaders in free elections important for democracy
sum Q243 Q181 if client == 1
scatter Q243 Q181 if client == 1, mlabel(B_ECONOMY_ALPHA) msymbol(0) mlabpos(0) ms(i) xline(2.10524) yline(7.78872) mlabsize(3)
graph export figure7.png, replace
********
*  FIGURE 8

* justifiability of corruption (inverse of moral condemnation of corruption) vs degree to which state providing for unemployed are important for democracy
sum Q244 Q181 if client == 1
scatter Q244 Q181 if client == 1, mlabel(B_ECONOMY_ALPHA) msymbol(0) mlabpos(0) ms(i) xline(2.10524) yline(6.850628) mlabsize(3) 
graph export figure8.png, replace

********
* SUMMARY FIGURE C

* justifiability of corruption (inverse of moral condemnation of corruption) vs average of the four rights variables
sum avg_rights Q181 if client == 1
scatter avg_rights Q181 if client == 1, mlabel(B_ECONOMY_ALPHA) msymbol(0) mlabpos(0) ms(i) xline(2.10524) yline(7.396523) mlabsize(3) 
graph export summaryfigurec.png, replace



* The data was exported to Excel to produce the charts in the report. The charts in the report should match those above.

save "WVS_ECONOMY_level_human_rights.dta", replace